# Anyforce Core

The API / Dynamic Models part of anyforce

## Install Dependencies

```bash
make vendor
```

## Lint

- Lint [flask8](https://flake8.pycqa.org/en/latest/)
- Type Check [pyright](https://github.com/microsoft/pyright)

### Run Lint

```bash
make lint
```

## Test

```bash
make test
```
